import { ComponentMetaType, CPageDataType } from '../types/page';
import { DataModelEmitterType } from '../util/modelEmitter';
import { CRootNode } from './RootNode';
import { ExportType } from '../const/schema';
import { CMaterials } from '../Material';
import { CNode } from './RootNode/Node';
import { CNodeDataType } from '../types/node';
import { AssetPackage } from '../types/base';
import { CMaterialType } from '../types/material';
export declare const checkPage: (data: any) => CPageDataType;
export declare const parsePage: (data: CPageDataType, parent: CPage, materials: CMaterials) => {
    componentsTree: CRootNode;
    version: string;
    name: string;
    css?: import('../types/base').CSSType[];
    lifecycle?: {
        beforeMount?: import('../types/page').LifecycleItem[];
        didMount?: import('../types/page').LifecycleItem[];
        beforeUnmount?: import('../types/page').LifecycleItem[];
    };
    props?: Record<string, any>;
    methods?: import('../types/node').FunctionPropType[];
    componentsMeta: ComponentMetaType[];
    thirdLibs?: import('../types/base').LibMetaType[];
    assets?: AssetPackage[];
    extra?: any;
};
export type CPpageDataModelType = Omit<CPageDataType, 'componentsTree'> & {
    componentsTree: CRootNode;
};
export type PosObj = {
    type: 'CHILD';
    index: number;
    pos: 'BEFORE' | 'AFTER';
};
export type InsertNodePosType = 'BEFORE' | 'AFTER' | 'CHILD_START' | 'CHILD_END' | PosObj;
export declare class CPage {
    nodeType: "PAGE";
    rawData: CPageDataType;
    emitter: DataModelEmitterType;
    data: CPpageDataModelType;
    parent: null | undefined;
    materialsModel: CMaterials;
    assetPackagesList: AssetPackage[];
    constructor(data: CPageDataType, options?: {
        materials?: CMaterialType[];
        assetPackagesList?: AssetPackage[];
    });
    updatePage(data: CPageDataType): void;
    reloadPage(data?: CPageDataType): void;
    get value(): CPpageDataModelType;
    getNode(id?: string): CNode | CRootNode | undefined;
    addNode(newNode: CNode, targetNode: CNode | CRootNode, pos?: InsertNodePosType): boolean;
    createNode(nodeData: CNodeDataType): CNode;
    addNodeById(newNode: CNode, targetNodeId: string, pos?: InsertNodePosType): boolean;
    copyNode(node: CNode): CNode;
    copyNodeById(nodeId: string): false | CNode;
    moveNode(from: CNode, to: CNode, pos: InsertNodePosType): boolean;
    moveNodeById(fromId: string, toId: string, pos: InsertNodePosType): boolean;
    deleteNode(node: CNode | CRootNode): string | CNode | undefined;
    deleteNodeById(nodeId: string): string | CNode | undefined;
    export(mode?: ExportType): CPageDataType;
    getRootNode(): CRootNode;
}
export declare const EmptyPage: CPageDataType;
