import { LibMetaType, AssetPackage, CSSType } from './base';
import { FunctionPropType } from './node';
import { CRootNodeDataType } from './rootNode';
import { CNode } from '../Page/RootNode/Node';
import { CPage } from '../Page';
import { CRootNode } from '../Page/RootNode';
export type ComponentMetaType = {
    componentName: string;
} & LibMetaType;
export declare enum RenderType {
    PAGE = "PAGE",
    COMPONENT = "COMPONENT"
}
export type LifecycleItem = {
    nodeId: string;
    run: (params: {
        ctx: any;
    }) => void;
};
export type CPageDataType<T = any> = {
    version: string;
    name: string;
    css?: CSSType[];
    lifecycle?: {
        beforeMount?: LifecycleItem[];
        didMount?: LifecycleItem[];
        beforeUnmount?: LifecycleItem[];
    };
    /** 页面级 别 或者组件级别的外部传入的 props, 用于数据交互，比如通过平台导出源码，直接集成到 pro code 项目中使用 */
    props?: Record<string, any>;
    methods?: FunctionPropType[];
    componentsMeta: ComponentMetaType[];
    thirdLibs?: LibMetaType[];
    componentsTree: CRootNodeDataType;
    assets?: AssetPackage[];
    extra?: T;
};
export declare const CPageDataTypeDescribe: import('superstruct').Struct<{
    componentsTree: {
        [x: string]: any;
    };
    componentsMeta: {
        package: string;
        version: string;
        name: string;
        componentName: string;
        exportName?: string | undefined;
        destructuring?: boolean | undefined;
        subName?: string | undefined;
        main?: string | undefined;
        cssPaths?: string[] | undefined;
    }[];
    version?: string | undefined;
    name?: string | undefined;
    css?: string | undefined;
    lifecycle?: any;
    props?: any;
    methods?: {
        type: import("..").CNodePropsTypeEnum.FUNCTION;
        value: string;
    }[] | undefined;
    thirdLibs?: {
        package: string;
        version: string;
        name: string;
        exportName?: string | undefined;
        destructuring?: boolean | undefined;
        subName?: string | undefined;
        main?: string | undefined;
        cssPaths?: string[] | undefined;
    }[] | undefined;
    assets?: any[] | undefined;
    extra?: any;
}, {
    version: import('superstruct').Struct<string | undefined, null>;
    name: import('superstruct').Struct<string | undefined, null>;
    css: import('superstruct').Struct<string | undefined, null>;
    lifecycle: import('superstruct').Struct<any, null>;
    props: import('superstruct').Struct<any, null>;
    methods: import('superstruct').Struct<{
        type: import("..").CNodePropsTypeEnum.FUNCTION;
        value: string;
    }[] | undefined, import('superstruct').Struct<{
        type: import("..").CNodePropsTypeEnum.FUNCTION;
        value: string;
    }, {
        type: import('superstruct').Struct<import("..").CNodePropsTypeEnum.FUNCTION, import("..").CNodePropsTypeEnum.FUNCTION>;
        value: import('superstruct').Struct<string, null>;
    }>>;
    componentsMeta: import('superstruct').Struct<{
        package: string;
        version: string;
        name: string;
        componentName: string;
        exportName?: string | undefined;
        destructuring?: boolean | undefined;
        subName?: string | undefined;
        main?: string | undefined;
        cssPaths?: string[] | undefined;
    }[], import('superstruct').Struct<{
        package: string;
        version: string;
        name: string;
        componentName: string;
        exportName?: string | undefined;
        destructuring?: boolean | undefined;
        subName?: string | undefined;
        main?: string | undefined;
        cssPaths?: string[] | undefined;
    }, {
        package: import('superstruct').Struct<string, null>;
        version: import('superstruct').Struct<string, null>;
        name: import('superstruct').Struct<string, null>;
        exportName: import('superstruct').Struct<string | undefined, null>;
        destructuring: import('superstruct').Struct<boolean | undefined, null>;
        subName: import('superstruct').Struct<string | undefined, null>;
        main: import('superstruct').Struct<string | undefined, null>;
        cssPaths: import('superstruct').Struct<string[] | undefined, import('superstruct').Struct<string, null>>;
        componentName: import('superstruct').Struct<string, null>;
    }>>;
    thirdLibs: import('superstruct').Struct<{
        package: string;
        version: string;
        name: string;
        exportName?: string | undefined;
        destructuring?: boolean | undefined;
        subName?: string | undefined;
        main?: string | undefined;
        cssPaths?: string[] | undefined;
    }[] | undefined, import('superstruct').Struct<{
        package: string;
        version: string;
        name: string;
        exportName?: string | undefined;
        destructuring?: boolean | undefined;
        subName?: string | undefined;
        main?: string | undefined;
        cssPaths?: string[] | undefined;
    }, {
        package: import('superstruct').Struct<string, null>;
        version: import('superstruct').Struct<string, null>;
        name: import('superstruct').Struct<string, null>;
        exportName: import('superstruct').Struct<string | undefined, null>;
        destructuring: import('superstruct').Struct<boolean | undefined, null>;
        subName: import('superstruct').Struct<string | undefined, null>;
        main: import('superstruct').Struct<string | undefined, null>;
        cssPaths: import('superstruct').Struct<string[] | undefined, import('superstruct').Struct<string, null>>;
    }>>;
    componentsTree: import('superstruct').Struct<{
        [x: string]: any;
    }, {
        [x: string]: import('superstruct').Struct<any, any>;
        componentName: import('superstruct').Struct<import('./rootNode').InnerComponentNameEnum, import('./rootNode').InnerComponentNameEnum>;
    }>;
    assets: import('superstruct').Struct<any[] | undefined, import('superstruct').Struct<any, null>>;
    extra: import('superstruct').Struct<any, null>;
}>;
export type CPageNode = CNode | CPage | CRootNode;
